#
# spec file for package python-securesystemslib
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-securesystemslib
Version:        1.2.0
Release:        1.2
Summary:        Cryptographic and general routines for Secure Systems Lab
License:        MIT
URL:            https://github.com/secure-systems-lab/securesystemslib
Source:         https://files.pythonhosted.org/packages/source/s/securesystemslib/securesystemslib-%{version}.tar.gz
BuildRequires:  %{python_module PyKCS11}
BuildRequires:  %{python_module asn1crypto}
BuildRequires:  %{python_module cryptography >= 3.3.2}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyKCS11
Requires:       python-asn1crypto
Requires:       python-cryptography
BuildArch:      noarch
%python_subpackages

%description
Cryptographic and general-purpose routines for Secure Systems Lab projects at NYU

%prep
%autosetup -p1 -n securesystemslib-%{version}
# Remove exec permission from python scripts
find . -type f -name *.py -exec chmod 0644 {} \;

%build
%pyproject_wheel

%install
%pyproject_install
# Remove not needed files
%{python_expand #
rm -rf %{buildroot}%{$python_sitelib}/securesystemslib/_vendor/ed25519/.gitignore
}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# spinhcs+ key support requires the pyspx library
donttest="test_sphincs"
# remove the ed25519 tests, the module is "Not Recommended For New Applications: Use pynacl Instead"
rm securesystemslib/_vendor/ed25519/test_ed25519.py
%pytest -k "not ($donttest)"

%files %{python_files}
%{python_sitelib}/securesystemslib
%{python_sitelib}/securesystemslib-%{version}*info

%changelog
* Mon Feb 10 2025 Dirk Müller <dmueller@suse.com>
- update to 1.2.0:
  * Small release with mostly internal changes.
  * SigstoreSigner now has a convenience function for creating a
    signing identity for GitHub Actions workflow
  * Linting refactoring, switched to ruff
  * Modern annotations used in most of the code base
* Tue Jan 14 2025 Markéta Machová <mmachova@suse.com>
- Remove ed25519 tests to avoid that module in Leap
* Thu Oct 31 2024 Daniel Garcia <daniel.garcia@suse.com>
- Remove not needed patch use_python3_interpreter_in_tests.diff
- Move not mandatory requirements to Suggests
- Update to version 1.1.0:
  * SigstoreSigner: Re-enable compatibility with Sigstore (#781)
- 1.0.0:
  Added
  * Signer: add public_key attribute to interface (#756)
  * VaultSigner: Signer implementation for HashiCorp Vault (#800)
  * CryptoSigner: support ecdsa keytype that is no longer in spec (#711)
  * CryptoSigner: add private_bytes property (#799)
  * CryptoSigner: add "file2" signer uri (#759)
  * test: use localstack to test AWSSigner (#777)
  Removed
  * CryptoSigner: remove "file" signer uri (#759)
  * migration script for legacy keys (#770)
  * SSlibSigner class and *_securesystemslib_key methods (#771)
  * legacy key key*, interface, util and schema modules (#772, #773, #776)
  * unused functions in hash, and formats module (#774, #776)
  * unused global key constants (#806)
  Changed
  * SSlibKey: strengthen input validation (#780, #795)
  * AWSSigner: support default scheme and add stronger input validation (#724, #778)
  * dsse: change Envelope.signatures type to dict (#743)
  * vendor: update ed25519 copy (#793)
  * docs: improve user and contributor docs (#744, #745, #746, #749, #759, #796)
  * test: improve and temporarily disable SigstoreSigner test (#779, #785)
  * ci: use dependabot groups, update weekly (#735)
  * ci: test macOS and Windows on latest Python only (#797)
  * Make securessystemslib.gpg internal (#792)
  Fixed
  * Fix check-upstream-ed25519 workflow permission (#706)
  * SSlibKey: fix default scheme and test for ecdsa nistp384 key (#763 #794)
  [...]
  Other release notes can be found in the CHANGELOG.md file:
  https://github.com/secure-systems-lab/securesystemslib/blob/v1.1.0/CHANGELOG.md
* Mon Mar 27 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch use_python3_interpreter_in_tests.diff:
  * Call python3, not python.
- Actually run the testsuite.
- Fix the Summary, and run fdupes to fix the most egregious rpmlint issues.
- Stop using %%{python_sitelib}/*.
* Fri Dec 10 2021 Adrian Schröter <adrian@suse.de>
- initial package of version 0.21.0
